pub struct CPUConfig {
pub cpuid_modifiers: Vec<CpuIdModifier>,
pub msr_modifiers: Vec<MsrModifier>,
pub reg_modifiers: Vec<RegModifier>,
}Expand description
The CPU configuration template defines a set of bit maps as modifiers of flags accessed by register to be disabled/enabled for the microvm.
Fields
cpuid_modifiers: Vec<CpuIdModifier>msr_modifiers: Vec<MsrModifier>reg_modifiers: Vec<RegModifier>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for CPUConfig
impl<'de> Deserialize<'de> for CPUConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CPUConfig
Sourceimpl Ord for CPUConfig
impl Ord for CPUConfig
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for CPUConfig
impl PartialOrd for CPUConfig
impl StructuralPartialEq for CPUConfig